# eric7.Plugins.VcsPlugins.vcsGit.GitCherryPickDialog

Module implementing a dialog to enter cherry-pick data.

### Global Attributes

None

### Classes

GitCherryPickDialog | Class implementing a dialog to enter cherry-pick data.

### Functions

None

## GitCherryPickDialog

Class implementing a dialog to enter cherry-pick data.

### Derived from

QDialog, Ui_GitCherryPickDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitCherryPickDialog | Constructor
getData | Public method to retrieve the entered data.
on_commitsEdit_textChanged | Private slot to react upon changes of commits.

### Static Methods

None

#### GitCherryPickDialog (Constructor)

GitCherryPickDialog(commits=None, parent=None)

Constructor

commits (list of str)
  list of commits to show in the commits pane
parent (QWidget)
  reference to the parent widget

#### GitCherryPickDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple with list of commits, a flag indicating to append cherry-pick info to the commit message, a flag indicating to append a signed-off-by line to the commit message and a flag indicating to not commit the action

Return Type:
  tuple of (list of str, bool, bool, bool)

#### GitCherryPickDialog.on_commitsEdit_textChanged

on_commitsEdit_textChanged()

Private slot to react upon changes of commits.

Up